==> piwigo-11.5.0.zip: piwigo/themes/modus/language/it_IT/theme.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['modus_theme'] = 'modus_theme';
$lang['Explore'] = 'Explora';
$lang['%d albums'] = '%d albums';
$lang['%d album'] = '%d album';
$lang['Skin'] = 'Stile';
$lang['Use square thumbs'] = 'Utilizza le miniature quadrate';
$lang['Modus theme config'] = 'Configurazione tema Modus';
$lang['Default size for thumbnails on high density display (retina)'] = 'Dimensione predefinita per le miniature sul display ad alta densità (retina)';
$lang['Default sizes'] = 'Dimensioni predefinite';
$lang['Album thumbnails'] = 'Miniature album';
$lang['Default size for thumbnails'] = 'Dimensione predefinita per le miniature';
$lang['%d pixels'] = '%d pixels';
$lang['Display page banner'] = 'Visualizza pagina banner';

==> piwigo-16.0.0.zip: piwigo/themes/modus/language/it_IT/theme.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['modus_theme'] = 'modus_theme';
$lang['Explore'] = 'Esplora';
$lang['%d albums'] = '%d albums';
$lang['%d album'] = '%d album';
$lang['Skin'] = 'Stile';
$lang['Use square thumbs'] = 'Utilizza le miniature quadrate';
$lang['Modus theme config'] = 'Configurazione tema Modus';
$lang['Default size for thumbnails on high density display (retina)'] = 'Dimensione predefinita per le miniature sul display ad alta densità (retina)';
$lang['Default sizes'] = 'Dimensioni predefinite';
$lang['Album thumbnails'] = 'Miniature album';
$lang['Default size for thumbnails'] = 'Dimensione predefinita per le miniature';
$lang['%d pixels'] = '%d pixels';
$lang['Display page banner'] = 'Visualizza pagina banner';
$lang['Admin'] = 'Amm.';
